# coding=UTF-8
#------------------------------------------------------------------------------
# Copyright (c) Acoular Development Team.
#------------------------------------------------------------------------------

# separate file to find out about version without importing the acoular lib
__author__ = "Acoular Development Team"
__date__ = "11 March 2024"
__version__ = "24.03"
